import { Controller, Get, UseInterceptors } from '@nestjs/common'
import { UsersService } from './users.service'
import { ApiOperation, ApiTags } from '@nestjs/swagger'
import { User } from 'src/common/decorators/user.decorator'
import { NeedAuth } from 'src/common/decorators/need-auth.decorator'
import { PasswordInterceptor } from 'src/common/interceptors/password.interceptor'

@ApiTags('User')
@Controller('api/users')
export class UsersController {
  constructor(private readonly userService: UsersService) {}

  @ApiOperation({ summary: '获取用户信息' })
  @UseInterceptors(PasswordInterceptor)
  @NeedAuth()
  @Get('me')
  async getUserInfo(@User('userId') userId: string) {
    const user = await this.userService.findUser({ id: userId })
    return user
  }
}
